# `pretf_helpers`

## Description

This is a set of functions and classes to make using `pretf` easier and "more Pythonic".

## Installation

Use `pip`

## License

This package is licensed under the [**MPL 2.0** license](https://www.mozilla.org/en-US/MPL/2.0/FAQ/).

Do note that this means (my interpretation):

 * Only files explicitly part of this package must be kept open source.
 * If you add _your own_ files to this package, you are NOT required to open source those files.
 * If you use this package in your software, you are NOT required to open source your software.

Full license text is available in the `LICENSE` file.
